@@ -30,14 +30,20 @@ class StimulusNormedL1(tf.keras.regularizers.Regularizer):
     def __init__(self, l1=0.):
         """Initialize.
 
-        Arguments:
+        Args:
             l1: Rate of L1 regularization.
 
         """
         self.l1 = l1
 
     def __call__(self, z):
-        """Call."""
+        """Call.
+
+        Args:
+            z: A Tensor representing percepts.
+                shape=[n_stimuli, n_dim].
+
+        """
         return self.l1 * (tf.reduce_sum(tf.abs(z)) / z.shape[0])
 
     def get_config(self):
